pub struct CcHash { /* private fields */ }Expand description
CRYPTOCELL HASH engine
Implementations
Sourceimpl CcHash
impl CcHash
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn hash_h(self, n: usize) -> Reg<u32, RW>
pub const fn hash_h(self, n: usize) -> Reg<u32, RW>
Description collection: HASH_H value registers. The initial HASH_H[0] register holds the least significant bits [31:0] of the value.
Sourcepub const fn hash_pad_auto(self) -> Reg<HashPadAuto, W>
pub const fn hash_pad_auto(self) -> Reg<HashPadAuto, W>
Configure the HASH engine to automatically pad data at the end of the DMA transfer to complete the digest operation.
Sourcepub const fn hash_xor_din(self) -> Reg<u32, RW>
pub const fn hash_xor_din(self) -> Reg<u32, RW>
Perform an XOR operation of the DIN DMA engine input data being fed into the HASH engine. Set this register to ‘0’ if XOR is not required.
Sourcepub const fn hash_init_state(self) -> Reg<HashInitState, W>
pub const fn hash_init_state(self) -> Reg<HashInitState, W>
Configure HASH engine initial state registers.
Sourcepub const fn hash_select(self) -> Reg<HashSelect, W>
pub const fn hash_select(self) -> Reg<HashSelect, W>
Select HASH or GHASH engine as the digest engine to use.
Sourcepub const fn hash_control(self) -> Reg<HashControl, RW>
pub const fn hash_control(self) -> Reg<HashControl, RW>
Control the HASH engine behavior.
Sourcepub const fn hash_pad(self) -> Reg<HashPad, RW>
pub const fn hash_pad(self) -> Reg<HashPad, RW>
Enable the hardware padding feature of the HASH engine.
Sourcepub const fn hash_pad_force(self) -> Reg<HashPadForce, RW>
pub const fn hash_pad_force(self) -> Reg<HashPadForce, RW>
Force the hardware padding operation to trigger if the input data length is zero bytes.
Sourcepub const fn hash_cur_len_0(self) -> Reg<u32, RW>
pub const fn hash_cur_len_0(self) -> Reg<u32, RW>
Bits [31:0] of the number of bytes that have been digested so far.
Sourcepub const fn hash_cur_len_1(self) -> Reg<u32, RW>
pub const fn hash_cur_len_1(self) -> Reg<u32, RW>
Bits [63:32] of the number of bytes that have been digested so far.
Sourcepub const fn hash_hw_flags(self) -> Reg<HashHwFlags, R>
pub const fn hash_hw_flags(self) -> Reg<HashHwFlags, R>
Hardware configuration of the HASH engine. Reset value holds the supported features.
Sourcepub const fn hash_sw_reset(self) -> Reg<HashSwReset, W>
pub const fn hash_sw_reset(self) -> Reg<HashSwReset, W>
Reset the HASH engine.
Sourcepub const fn hash_endianness(self) -> Reg<HashEndianness, RW>
pub const fn hash_endianness(self) -> Reg<HashEndianness, RW>
Configure the endianness of HASH data and padding generation.